function PsychSetup(singledisplay,tripledisplay,progpath,projector,screen1distance,screen1radius,screen2distance,screen2radius)

    % You can hard-code the following 2 values to match your screen setup.
    % Caution! This overwrites the input from the GUI to this function.
    
%     triplehead = 2; % position of multi-display adapter (1, 2 or 3)
%     singledisplay = 3; % position of single stimulus screen (1, 2 or 3)

    % The following lines read the default setup of your screens.
    Screen('Preference', 'VisualDebugLevel', 1);
    % Screen('CloseAll');
    [width1, height1] = Screen('WindowSize', tripledisplay);
    [width2, height2] = Screen('WindowSize', singledisplay);
    % Use get(0,'MonitorPositions') to reveal monitor position coordinates
    % in pixels of your specific display setup, e.g.: 
    %  -799         481         800         600
    %     1           1        1920        1080
    % -3199         481        2400         600
    % Here, the first row corresponds to the single stimulus display,
    % the second row corresponds to the main GUI screen,
    % and the third row corresponds to the multi-display adapter.
    % Columns correspond to x (top left corner), y (top left corner),
    % x (bottom right corner), y (bottom right corner).
    
    % Now, set the desired pixel offset of your multi-display adapter.
    % For "no offset", choose r = [1 1 width height];
    p1 = [1-(width1+width2), 1, -width2, height1];

    % Now, set the desired pixel offset of your single display screen.
    % For "no offset", choose r2 = [1 1 width2 height2];
    p2 = [1-width2, 1, 0, height2];

    
    % You should not need to edit any code below this line. %%%%%%%%

%     r1 = [300 200 1100 800];
%     r2 = [400 300 1200 900];
    
    if projector
        
        projector1 = tripledisplay;
        projector2 = singledisplay;
        
        % Assign desired screen offsets.
        w1 = Screen('OpenWindow',projector1,[],p1);
        w2 = Screen('OpenWindow',projector2,[],p2);        
        
        Screen1rect = [0 0 width1 height1];
        Screen2rect = [0 0 width2 height2];
        lineRect1 = [0 0 width1 1];
        lineRect2 = [0 0 width2 1];
        
    else
        
        % Assign desired screen offsets.
        w1 = Screen('OpenWindow',tripledisplay,[],p1);
        w2 = Screen('OpenWindow',singledisplay,[],p2);

        % multi-display adapter
        Screen1rectd1 = [0               0   fix(width1/3) height1];
        Screen1rectd2 = [fix(width1/3)   0 2*fix(width1/3) height1];
        Screen1rectd3 = [2*fix(width1/3) 0 3*fix(width1/3) height1];

        % single stimulus display
        Screen2rect = [0 0 fix(width1/3) height1];

        % pseudo-rectangular stimulus outline
        lineRect1 = [0 0 fix(width1/3) 1];
        lineRect2 = [0 0 width2 1];
        
    end

    % enable alpha blending (transparency)
    Screen('BlendFunction', w1, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);  
    Screen('BlendFunction', w2, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);

    white=WhiteIndex(singledisplay);
    black=BlackIndex(singledisplay);
    gray=(white+black)/2;
    fog1 = Screen('MakeTexture', w1, gray);
    fog2 = Screen('MakeTexture', w2, gray);

    if projector
        
        % screenXnearest: distance between projector X and nearest point of
        % screen X (i.e., the screen centre), X = 1 or 2
        % screenXdistance: distance between projector X and fish
        % screenXradius: distance between fish and cylindrical screen X
        screen1nearest = screen1distance - screen1radius;
        screen2nearest = screen2distance - screen2radius;

        [x1,y1] = meshgrid(-fix(width1/2)+1/2:fix(width1/2),-fix(height1/2):fix(height1/2)-1/2);
        [x2,y2] = meshgrid(-fix(width2/2)+1/2:fix(width2/2),-fix(height2/2):fix(height2/2)-1/2);
        
%         phi = @(x,r1,r3) ...
%               asin(1/r3 * r1*(r1-r3)*x./(x.^2+(r1-r3)^2) - sign(x) .* sqrt((r1*(r1-r3)*x./(x.^2+(r1-r3)^2)).^2  -  x.^2*(r1^2-r3^2)./(x.^2+(r1-r3)^2)));
%         phi = @(x,r1,r3) ...
%               asin(1/r3 * sign(x) .* ...
%               (-sqrt(x.^2 .* (r1^2*r3^2 - r1^2*x.^2 - 2*r1*r3^3 + r3^4 + r3^2*x.^2)) ...
%                + r1^2*abs(x) - r1*r3*abs(x))./(r1^2-2*r1*r3+r3^2+x.^2));
          
        phi = @(x,r1,r3) ...
              asin(1/r3 * sign(x) .* ...
                   (-sqrt(x.^2 .* (r3^2*(r1-r3)^2 - (r1^2-r3^2)*x.^2)) ...
                    + abs(x)*r1*(r1-r3))  ./  ((r1-r3)^2+x.^2));
                
        screen1xmax = screen1nearest * sqrt(1/(1-screen1radius^2/screen1distance^2) - 1);
        screen2xmax = screen2nearest * sqrt(1/(1-screen2radius^2/screen2distance^2) - 1);
        
        x1scaled = x1 / abs(max(x1(1,:))) * screen1xmax;
        x2scaled = x2 / abs(max(x2(1,:))) * screen2xmax;
        
%         horizontang1 = phi(x1scaled(1,:),screen1distance,screen1radius);
%         horizontang2 = phi(x2scaled(1,:),screen2distance,screen2radius);
        horizontang1 = real(phi(x1scaled,screen1distance,screen1radius));
        horizontang2 = real(phi(x2scaled,screen2distance,screen2radius));
        
        vertang1 = atan2(y1/screen1nearest .* ...
                         sqrt(x1scaled.^2+screen1nearest^2) .* ...
                         (1+screen1radius/screen1nearest*(1-cos(horizontang1))), ...
                         screen1radius);
        vertang2 = atan2(y2/screen2nearest .* ....
                         sqrt(x2scaled.^2+screen2nearest^2) .* ...
                         (1+screen2radius/screen2nearest*(1-cos(horizontang2))), ...
                         screen2radius);

        maxangle1 = atan2(height1/2,screen1radius);
        maxangle2 = atan2(height2/2,screen2radius);
        
        vertang1 = vertang1/vertang1(floor(end/2))*maxangle1;
        vertang2 = vertang2/vertang2(floor(end/2))*maxangle2;
        
        vertalpha1 = (abs(vertang1)>maxangle1).*255+(abs(vertang1)<=maxangle1).*0;
        vertalpha2 = (abs(vertang2)>maxangle2).*255+(abs(vertang2)<=maxangle2).*0;        
        
    else
        
        rad1_screen1 = width1/2/3;
        rad1_screen2 = width2/2;
        rad2_screen1 = rad1_screen1*sqrt(2);
        rad2_screen2 = rad1_screen2*sqrt(2);

        [x1,y1] = meshgrid(-fix((width1/2)/3)+1/2 : fix((width1/2)/3), ...
                           -fix(height1/2) : fix(height1/2)-1/2);
        [x2,y2] = meshgrid(-fix(width2/2)+1/2 : fix(width2/2), ...
                           -fix(height2/2) : fix(height2/2)-1/2);
                       
        % pixelhorizang = atan(pixelx/screencentre)
        horizontang1 = atan2(x1(1,:), rad1_screen1); 
        horizontang2 = atan2(x2(1,:), rad1_screen2);
        
        % pixelvertang = atan(pixely/pixeldistance)
        vertang1 = atan2(y1, (x1.^2+rad1_screen1.^2).^0.5);
        vertang2 = atan2(y2, (x2.^2+rad1_screen2.^2).^0.5);
        
        % atan(screenhalfheight/screenside)
        maxangle1 = atan2(height1/2,rad2_screen1);
        maxangle2 = atan2(height2/2,rad2_screen2);
        
        vertalpha1 = (abs(vertang1)>maxangle1).*255+(abs(vertang1)<=maxangle1).*0;
        vertalpha2 = (abs(vertang2)>maxangle2).*255+(abs(vertang2)<=maxangle2).*0;
        
    end
    
    vertmask1(:,:,4) = vertalpha1;
    vertmask2(:,:,4) = vertalpha2;
    
    for i=1:3
        vertmask1(:,:,i) = 0;
        vertmask2(:,:,i) = 0;
    end
    
    VBLTimestamp1 = Screen(w1,'Flip'); %#ok<NASGU>
    VBLTimestamp2 = Screen(w2,'Flip'); %#ok<NASGU>

    cd(progpath)
    if projector

        save('PsychSetup.mat','w1','w2','fog1','fog2','lineRect1','lineRect2', ...
                              'vertmask1','vertmask2','gray', ...
                              'width1','width2','height1','height2', ...
                              'horizontang1','horizontang2', ...
                              'Screen1rect','Screen2rect', ...
                              'VBLTimestamp1','VBLTimestamp2')
                          
    else
        
        save('PsychSetup.mat','w1','w2','fog1','fog2','lineRect1','lineRect2', ...
                              'vertmask1','vertmask2','gray', ...
                              'width1','width2','height1','height2', ...
                              'horizontang1','horizontang2', ...
                              'Screen1rectd1','Screen1rectd2', ...
                              'Screen1rectd3','Screen2rect', ...
                              'VBLTimestamp1','VBLTimestamp2')
                          
    end
    
end